betty.asyncio module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.asyncio module

Provide asynchronous programming utilities.

async betty.asyncio.gather(*coroutines: Coroutine[Any, None, _T]) → tuple[_T, ...]

  Gather multiple coroutines.

  This is like Python’s own `asyncio.gather`, but with improved error handling.

betty.asyncio.wait_to_thread(f: Awaitable[_T]) → _T

  Wait for an awaitable in another thread.